slepc-3.18.0 2022-10-01
Report Typos and Errors

# LMEGetMonitorContext

Gets the monitor context, as set by LMEMonitorSet() for the FIRST monitor only.

### Synopsis

    #include "slepclme.h"
    PetscErrorCode LMEGetMonitorContext(LME lme,void *ctx)

Not Collective

### Input Parameter

| lme | - linear matrix equation solver context obtained from LMECreate()

### Output Parameter

| ctx | - monitor context

### See Also

LMEMonitorSet()

### Level

intermediate

### Location

src/lme/interface/lmemon.c
Index of all LME routines
Table of Contents for all manual pages
Index of all manual pages